==> eam-wshub-proxyclient-11.5-13-sources.jar: net/datastream/schemas/mp_functions/mp0109_001/MP0109_AddComments_001.java <==

package net.datastream.schemas.mp_functions.mp0109_001;

import javax.xml.bind.annotation.XmlAccessType;
import javax.xml.bind.annotation.XmlAccessorType;
import javax.xml.bind.annotation.XmlAttribute;
import javax.xml.bind.annotation.XmlElement;
import javax.xml.bind.annotation.XmlRootElement;
import javax.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COMMENT_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Classe Java pour anonymous complex type.
 * 
 * <p>Le fragment de schéma suivant indique le contenu attendu figurant dans cette classe.
 * 
 * <pre>
 * &lt;complexType>
 *   &lt;complexContent>
 *     &lt;restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       &lt;sequence>
 *         &lt;element ref="{http://schemas.datastream.net/MP_fields}COMMENT"/>
 *       &lt;/sequence>
 *       &lt;attribute name="isFromBatch" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="isFromWOQuickClose" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="bypassWorkOrderTypeAuthorization" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="is_gis_webservice_request" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       &lt;attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       &lt;attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Comments" />
 *       &lt;attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     &lt;/restriction>
 *   &lt;/complexContent>
 * &lt;/complexType>
 * </pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "comment"
})
@XmlRootElement(name = "MP0109_AddComments_001")
public class MP0109_AddComments_001 {

    @XmlElement(name = "COMMENT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected COMMENT_Type comment;
    @XmlAttribute(name = "isFromBatch")
    protected String isFromBatch;
    @XmlAttribute(name = "isFromWOQuickClose")
    protected String isFromWOQuickClose;
    @XmlAttribute(name = "bypassWorkOrderTypeAuthorization")
    protected String bypassWorkOrderTypeAuthorization;
    @XmlAttribute(name = "is_gis_webservice_request")
    protected String is_Gis_Webservice_Request;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Obtient la valeur de la propriété comment.
     * 
     * @return
     *     possible object is
     *     {@link COMMENT_Type }
     *     
     */
    public COMMENT_Type getCOMMENT() {
        return comment;
    }

    /**
     * Définit la valeur de la propriété comment.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMENT_Type }
     *     
     */
    public void setCOMMENT(COMMENT_Type value) {
        this.comment = value;
    }

    /**
     * Obtient la valeur de la propriété isFromBatch.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsFromBatch() {
        if (isFromBatch == null) {
            return "false";
        } else {
            return isFromBatch;
        }
    }

    /**
     * Définit la valeur de la propriété isFromBatch.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsFromBatch(String value) {
        this.isFromBatch = value;
    }

    /**
     * Obtient la valeur de la propriété isFromWOQuickClose.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsFromWOQuickClose() {
        if (isFromWOQuickClose == null) {
            return "false";
        } else {
            return isFromWOQuickClose;
        }
    }

    /**
     * Définit la valeur de la propriété isFromWOQuickClose.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsFromWOQuickClose(String value) {
        this.isFromWOQuickClose = value;
    }

    /**
     * Obtient la valeur de la propriété bypassWorkOrderTypeAuthorization.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBypassWorkOrderTypeAuthorization() {
        if (bypassWorkOrderTypeAuthorization == null) {
            return "false";
        } else {
            return bypassWorkOrderTypeAuthorization;
        }
    }

    /**
     * Définit la valeur de la propriété bypassWorkOrderTypeAuthorization.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBypassWorkOrderTypeAuthorization(String value) {
        this.bypassWorkOrderTypeAuthorization = value;
    }

    /**
     * Obtient la valeur de la propriété is_Gis_Webservice_Request.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Gis_Webservice_Request() {
        if (is_Gis_Webservice_Request == null) {
            return "false";
        } else {
            return is_Gis_Webservice_Request;
        }
    }

    /**
     * Définit la valeur de la propriété is_Gis_Webservice_Request.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Gis_Webservice_Request(String value) {
        this.is_Gis_Webservice_Request = value;
    }

    /**
     * Obtient la valeur de la propriété verb.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Définit la valeur de la propriété verb.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Obtient la valeur de la propriété noun.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.COMMENTS;
        } else {
            return noun;
        }
    }

    /**
     * Définit la valeur de la propriété noun.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Obtient la valeur de la propriété version.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Définit la valeur de la propriété version.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}

==> eam-wshub-proxyclient-12.1-1-sources.jar: net/datastream/schemas/mp_functions/mp0109_001/MP0109_AddComments_001.java <==

package net.datastream.schemas.mp_functions.mp0109_001;

import jakarta.xml.bind.annotation.XmlAccessType;
import jakarta.xml.bind.annotation.XmlAccessorType;
import jakarta.xml.bind.annotation.XmlAttribute;
import jakarta.xml.bind.annotation.XmlElement;
import jakarta.xml.bind.annotation.XmlRootElement;
import jakarta.xml.bind.annotation.XmlType;
import net.datastream.schemas.mp_fields.COMMENT_Type;
import net.datastream.schemas.mp_fields.NOUN_Type;
import net.datastream.schemas.mp_fields.VERB_Type;


/**
 * <p>Java class for anonymous complex type.
 * 
 * <p>The following schema fragment specifies the expected content contained within this class.
 * 
 * <pre>{@code
 * <complexType>
 *   <complexContent>
 *     <restriction base="{http://www.w3.org/2001/XMLSchema}anyType">
 *       <sequence>
 *         <element ref="{http://schemas.datastream.net/MP_fields}COMMENT"/>
 *       </sequence>
 *       <attribute name="isFromBatch" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       <attribute name="isFromWOQuickClose" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       <attribute name="bypassWorkOrderTypeAuthorization" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       <attribute name="is_gis_webservice_request" type="{http://schemas.datastream.net/MP_fields}FLAG_Type" default="false" />
 *       <attribute name="verb" type="{http://schemas.datastream.net/MP_fields}VERB_Type" fixed="Add" />
 *       <attribute name="noun" type="{http://schemas.datastream.net/MP_fields}NOUN_Type" fixed="Comments" />
 *       <attribute name="version" type="{http://schemas.datastream.net/MP_fields}VERSION" fixed="001" />
 *     </restriction>
 *   </complexContent>
 * </complexType>
 * }</pre>
 * 
 * 
 */
@XmlAccessorType(XmlAccessType.FIELD)
@XmlType(name = "", propOrder = {
    "comment"
})
@XmlRootElement(name = "MP0109_AddComments_001")
public class MP0109_AddComments_001 {

    @XmlElement(name = "COMMENT", namespace = "http://schemas.datastream.net/MP_fields", required = true)
    protected COMMENT_Type comment;
    @XmlAttribute(name = "isFromBatch")
    protected String isFromBatch;
    @XmlAttribute(name = "isFromWOQuickClose")
    protected String isFromWOQuickClose;
    @XmlAttribute(name = "bypassWorkOrderTypeAuthorization")
    protected String bypassWorkOrderTypeAuthorization;
    @XmlAttribute(name = "is_gis_webservice_request")
    protected String is_Gis_Webservice_Request;
    @XmlAttribute(name = "verb")
    protected VERB_Type verb;
    @XmlAttribute(name = "noun")
    protected NOUN_Type noun;
    @XmlAttribute(name = "version")
    protected String version;

    /**
     * Gets the value of the comment property.
     * 
     * @return
     *     possible object is
     *     {@link COMMENT_Type }
     *     
     */
    public COMMENT_Type getCOMMENT() {
        return comment;
    }

    /**
     * Sets the value of the comment property.
     * 
     * @param value
     *     allowed object is
     *     {@link COMMENT_Type }
     *     
     */
    public void setCOMMENT(COMMENT_Type value) {
        this.comment = value;
    }

    /**
     * Gets the value of the isFromBatch property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsFromBatch() {
        if (isFromBatch == null) {
            return "false";
        } else {
            return isFromBatch;
        }
    }

    /**
     * Sets the value of the isFromBatch property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsFromBatch(String value) {
        this.isFromBatch = value;
    }

    /**
     * Gets the value of the isFromWOQuickClose property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIsFromWOQuickClose() {
        if (isFromWOQuickClose == null) {
            return "false";
        } else {
            return isFromWOQuickClose;
        }
    }

    /**
     * Sets the value of the isFromWOQuickClose property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIsFromWOQuickClose(String value) {
        this.isFromWOQuickClose = value;
    }

    /**
     * Gets the value of the bypassWorkOrderTypeAuthorization property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getBypassWorkOrderTypeAuthorization() {
        if (bypassWorkOrderTypeAuthorization == null) {
            return "false";
        } else {
            return bypassWorkOrderTypeAuthorization;
        }
    }

    /**
     * Sets the value of the bypassWorkOrderTypeAuthorization property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setBypassWorkOrderTypeAuthorization(String value) {
        this.bypassWorkOrderTypeAuthorization = value;
    }

    /**
     * Gets the value of the is_Gis_Webservice_Request property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getIs_Gis_Webservice_Request() {
        if (is_Gis_Webservice_Request == null) {
            return "false";
        } else {
            return is_Gis_Webservice_Request;
        }
    }

    /**
     * Sets the value of the is_Gis_Webservice_Request property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setIs_Gis_Webservice_Request(String value) {
        this.is_Gis_Webservice_Request = value;
    }

    /**
     * Gets the value of the verb property.
     * 
     * @return
     *     possible object is
     *     {@link VERB_Type }
     *     
     */
    public VERB_Type getVerb() {
        if (verb == null) {
            return VERB_Type.ADD;
        } else {
            return verb;
        }
    }

    /**
     * Sets the value of the verb property.
     * 
     * @param value
     *     allowed object is
     *     {@link VERB_Type }
     *     
     */
    public void setVerb(VERB_Type value) {
        this.verb = value;
    }

    /**
     * Gets the value of the noun property.
     * 
     * @return
     *     possible object is
     *     {@link NOUN_Type }
     *     
     */
    public NOUN_Type getNoun() {
        if (noun == null) {
            return NOUN_Type.COMMENTS;
        } else {
            return noun;
        }
    }

    /**
     * Sets the value of the noun property.
     * 
     * @param value
     *     allowed object is
     *     {@link NOUN_Type }
     *     
     */
    public void setNoun(NOUN_Type value) {
        this.noun = value;
    }

    /**
     * Gets the value of the version property.
     * 
     * @return
     *     possible object is
     *     {@link String }
     *     
     */
    public String getVersion() {
        if (version == null) {
            return "001";
        } else {
            return version;
        }
    }

    /**
     * Sets the value of the version property.
     * 
     * @param value
     *     allowed object is
     *     {@link String }
     *     
     */
    public void setVersion(String value) {
        this.version = value;
    }

}
